==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/s3/kotlin/inputs/BucketReplicationConfigRuleDestinationMetricsEventThresholdArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.s3.kotlin.inputs

import com.pulumi.aws.s3.inputs.BucketReplicationConfigRuleDestinationMetricsEventThresholdArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property minutes Time in minutes. Valid values: `15`.
 */
public data class BucketReplicationConfigRuleDestinationMetricsEventThresholdArgs(
    public val minutes: Output<Int>,
) :
    ConvertibleToJava<com.pulumi.aws.s3.inputs.BucketReplicationConfigRuleDestinationMetricsEventThresholdArgs> {
    override fun toJava():
        com.pulumi.aws.s3.inputs.BucketReplicationConfigRuleDestinationMetricsEventThresholdArgs =
        com.pulumi.aws.s3.inputs.BucketReplicationConfigRuleDestinationMetricsEventThresholdArgs.builder()
            .minutes(minutes.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [BucketReplicationConfigRuleDestinationMetricsEventThresholdArgs].
 */
@PulumiTagMarker
public class BucketReplicationConfigRuleDestinationMetricsEventThresholdArgsBuilder internal
constructor() {
    private var minutes: Output<Int>? = null

    /**
     * @param value Time in minutes. Valid values: `15`.
     */
    @JvmName("vagwecjrmjuxamuh")
    public suspend fun minutes(`value`: Output<Int>) {
        this.minutes = value
    }

    /**
     * @param value Time in minutes. Valid values: `15`.
     */
    @JvmName("nurphnshcgjyaxuq")
    public suspend fun minutes(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.minutes = mapped
    }

    internal fun build(): BucketReplicationConfigRuleDestinationMetricsEventThresholdArgs =
        BucketReplicationConfigRuleDestinationMetricsEventThresholdArgs(
            minutes = minutes ?: throw PulumiNullFieldException("minutes"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/s3/kotlin/inputs/BucketReplicationConfigRuleDestinationMetricsEventThresholdArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.s3.kotlin.inputs

import com.pulumi.aws.s3.inputs.BucketReplicationConfigRuleDestinationMetricsEventThresholdArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property minutes Time in minutes. Valid values: `15`.
 */
public data class BucketReplicationConfigRuleDestinationMetricsEventThresholdArgs(
    public val minutes: Output<Int>,
) :
    ConvertibleToJava<com.pulumi.aws.s3.inputs.BucketReplicationConfigRuleDestinationMetricsEventThresholdArgs> {
    override fun toJava(): com.pulumi.aws.s3.inputs.BucketReplicationConfigRuleDestinationMetricsEventThresholdArgs =
        com.pulumi.aws.s3.inputs.BucketReplicationConfigRuleDestinationMetricsEventThresholdArgs.builder()
            .minutes(minutes.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [BucketReplicationConfigRuleDestinationMetricsEventThresholdArgs].
 */
@PulumiTagMarker
public class BucketReplicationConfigRuleDestinationMetricsEventThresholdArgsBuilder internal constructor() {
    private var minutes: Output<Int>? = null

    /**
     * @param value Time in minutes. Valid values: `15`.
     */
    @JvmName("alpcxbjtecsirtts")
    public suspend fun minutes(`value`: Output<Int>) {
        this.minutes = value
    }

    /**
     * @param value Time in minutes. Valid values: `15`.
     */
    @JvmName("quivcmayrwyfndak")
    public suspend fun minutes(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.minutes = mapped
    }

    internal fun build(): BucketReplicationConfigRuleDestinationMetricsEventThresholdArgs =
        BucketReplicationConfigRuleDestinationMetricsEventThresholdArgs(
            minutes = minutes ?: throw PulumiNullFieldException("minutes"),
        )
}
